@@ -7,18 +7,18 @@
 #define hex2c(c) ((c | 32) % 39 - 9)
 
 static int
-unescape(gh_buf *ob, const uint8_t *src, size_t size, int is_url)
+unescape(gh_buf *ob, const uint8_t *src, size_t size, bool unescape_plus)
 {
 	size_t  i = 0, org;
 
 	while (i < size) {
 		org = i;
-		while (i < size && src[i] != '%' && (!is_url || src[i] != '+'))
+		while (i < size && src[i] != '%' && src[i] != '+')
 			i++;
 
 		if (likely(i > org)) {
 			if (unlikely(org == 0)) {
-				if (i >= size && !is_url)
+				if (i >= size)
 					return 0;
 
 				gh_buf_grow(ob, HOUDINI_UNESCAPED_SIZE(size));
@@ -31,11 +31,12 @@ unescape(gh_buf *ob, const uint8_t *src, size_t size, int is_url)
 		if (i >= size)
 			break;
 
-		i++;
+		if (src[i++] == '+') {
+			gh_buf_putc(ob, unescape_plus ? ' ' : '+');
+			continue;
+		}
 
-        if (is_url && src[i - 1] == '+') {
-			gh_buf_putc(ob, ' ');
-        } else if (i + 1 < size && _isxdigit(src[i]) && _isxdigit(src[i + 1])) {
+		if (i + 1 < size && _isxdigit(src[i]) && _isxdigit(src[i + 1])) {
 			unsigned char new_char = (hex2c(src[i]) << 4) + hex2c(src[i + 1]);
 			gh_buf_putc(ob, new_char);
 			i += 2;
@@ -50,12 +51,18 @@ unescape(gh_buf *ob, const uint8_t *src, size_t size, int is_url)
 int
 houdini_unescape_uri(gh_buf *ob, const uint8_t *src, size_t size)
 {
-	return unescape(ob, src, size, 0);
+	return unescape(ob, src, size, false);
+}
+
+int
+houdini_unescape_uri_component(gh_buf *ob, const uint8_t *src, size_t size)
+{
+	return unescape(ob, src, size, false);
 }
 
 int
 houdini_unescape_url(gh_buf *ob, const uint8_t *src, size_t size)
 {
-	return unescape(ob, src, size, 1);
+	return unescape(ob, src, size, true);
 }
 
